<?php

namespace Drupal\Tests\bean_migrate\Kernel\Plugin\migrate\source;

use Drupal\Tests\migrate\Kernel\MigrateSqlSourceTestBase;

/**
 * Tests the "bean_title_field_formatter" migrate source plugin.
 *
 * @covers \Drupal\bean_migrate\Plugin\migrate\source\BeanTitleFieldFormatter
 * @group bean_migrate
 */
class BeanTitleFieldFormatterTest extends MigrateSqlSourceTestBase {

  /**
   * {@inheritdoc}
   *
   * @todo This should be changed to "protected" after Drupal core 8.x security
   *   support ends.
   * @see https://www.drupal.org/node/2909426
   */
  public static $modules = [
    'bean_migrate',
    'migrate_drupal',
  ];

  /**
   * {@inheritdoc}
   */
  public function providerSource() {
    $test_cases = [
      'All bundles' => [
        'Source' => [
          'bean' => [
            ['type' => 'simple'],
            ['type' => 'complicated'],
          ],
          'variable' => [
            [
              'name' => 'field_bundle_settings_bean__simple',
              'value' => serialize([
                'extra_fields' => [
                  'display' => [
                    'title' => [
                      'default' => [
                        'weight' => '-10',
                        'visible' => TRUE,
                      ],
                      'card' => [
                        'weight' => '11',
                        'visible' => FALSE,
                      ],
                    ],
                  ],
                ],
              ]),
            ],
            [
              'name' => 'field_bundle_settings_bean__complicated',
              'value' => serialize([
                'extra_fields' => [
                  'display' => [
                    'title' => [
                      'default' => [
                        'weight' => '-5',
                        'visible' => TRUE,
                      ],
                    ],
                  ],
                ],
              ]),
            ],
          ],
        ],
        'Expected' => [
          [
            'type' => 'simple',
            'view_mode' => 'default',
            'field_display_weight' => -10,
            'field_display_is_hidden' => FALSE,
          ],
          [
            'type' => 'simple',
            'view_mode' => 'card',
            'field_display_weight' => 11,
            'field_display_is_hidden' => TRUE,
          ],
          [
            'type' => 'complicated',
            'view_mode' => 'default',
            'field_display_weight' => -5,
            'field_display_is_hidden' => FALSE,
          ],
        ],
      ],
    ];
    $test_cases['Filtering for "complicated"'] = [
      'Source' => $test_cases['All bundles']['Source'],
      'Expected' => [
        [
          'type' => 'complicated',
          'view_mode' => 'default',
          'field_display_weight' => -5,
          'field_display_is_hidden' => FALSE,
        ],
      ],
      'Count' => NULL,
      'Plugin config' => [
        'type' => 'complicated',
      ],
    ];
    $test_cases['Filtering for a missing type'] = [
      'Source' => $test_cases['All bundles']['Source'],
      'Expected' => [],
      'Count' => NULL,
      'Plugin config' => [
        'type' => 'missing_type',
      ],
    ];

    return $test_cases;
  }

}
